/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hive.ql.ddl.database.create;

import java.io.Serializable;
import java.util.Map;

import org.apache.hadoop.hive.ql.ddl.DDLDesc;
import org.apache.hadoop.hive.ql.plan.Explain;
import org.apache.hadoop.hive.ql.plan.Explain.Level;

/**
 * DDL task description for CREATE DATABASE commands.
 */
@Explain(displayName = "Create Database", explainLevels = { Level.USER, Level.DEFAULT, Level.EXTENDED })
public class CreateDatabaseDesc implements DDLDesc, Serializable {
  private static final long serialVersionUID = 1L;

  private final String databaseName;
  private final String comment;
  private final String locationUri;
  private final String managedLocationUri;
  private final boolean ifNotExists;
  private final Map<String, String> dbProperties;

  public CreateDatabaseDesc(String databaseName, String comment, String locationUri, boolean ifNotExists,
      Map<String, String> dbProperties) {
    this(databaseName, comment, locationUri, ifNotExists, dbProperties, null);
  }

  public CreateDatabaseDesc(String databaseName, String comment, String locationUri, boolean ifNotExists,
      Map<String, String> dbProperties, String managedLocationUri) {
    this.databaseName = databaseName;
    this.comment = comment;
    this.locationUri = locationUri;
    this.ifNotExists = ifNotExists;
    this.dbProperties = dbProperties;
    this.managedLocationUri = managedLocationUri;
  }

  @Explain(displayName="if not exists", displayOnlyOnTrue = true)
  public boolean getIfNotExists() {
    return ifNotExists;
  }

  public Map<String, String> getDatabaseProperties() {
    return dbProperties;
  }

  @Explain(displayName="name", explainLevels = { Level.USER, Level.DEFAULT, Level.EXTENDED })
  public String getName() {
    return databaseName;
  }

  @Explain(displayName="comment")
  public String getComment() {
    return comment;
  }

  @Explain(displayName="locationUri")
  public String getLocationUri() {
    return locationUri;
  }

  @Explain(displayName="managedLocationUri")
  public String getManagedLocationUri() {
    return managedLocationUri;
  }
}
